@@ -39,7 +39,7 @@ use Carp;
 use Scalar::Util;
 use warnings::register;
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 use Cv::Constant qw(:all);
 
@@ -1692,23 +1692,6 @@ sub BoxPoints {
 	wantarray? @$pts : $pts;
 }
 
-
-=pod
-
-# ============================================================
-#  imgproc. Image Processing: Planar Subdivisions
-# ============================================================
-
-package Cv::Subdiv2D;
-sub DESTROY { }
-{ *CalcVoronoi = \&CalcSubdivVoronoi2D }
-{ *ClearVoronoi = \&ClearSubdivVoronoi2D }
-{ *CreateDelaunay = \&Cv::CreateSubdivDelaunay2D }
-{ *Locate = \&Subdiv2DLocate }
-{ *DelaunayInsert = \&SubdivDelaunay2DInsert }
-
-=cut
-
 # ============================================================
 #  imgproc. Image Processing: Motion Analysis and Object Tracking
 # ============================================================
